$.jqplot.shapeRenderer

The default jqPlot shape renderer. Given a set of points will plot them and either stroke a line (fill = false) or fill them (fill = true). If a filled shape is desired, closePath = true must also be set to close the shape.

Summary

$.jqplot.shapeRenderer | The default jqPlot shape renderer.
Properties |
linePattern | line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’
lineJoin | How line segments of the shadow are joined.
lineCap | how ends of the shadow line are rendered.
fill | whether to fill the shape.
isarc | whether the shadow is an arc or not.
fillRect | true to draw shape as a filled rectangle.
strokeRect | true to draw shape as a stroked rectangle.
clearRect | true to cear a rectangle.
strokeStyle | css color spec for the stoke style
fillStyle | css color spec for the fill style.
Functions |
draw | draws the shape.

### Properties

### linePattern

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’ characters such as ‘.-.’ or a numerical array like [draw, skip, draw, skip, ...] such as [1, 10] to draw a dotted line, [1, 10, 20, 10] to draw a dot-dash line, and so on.

### lineJoin

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

### lineCap

> this.lineCap = 'round'

how ends of the shadow line are rendered.

### fill

> this.fill = false

whether to fill the shape.

### isarc

> this.isarc = false

whether the shadow is an arc or not.

### fillRect

> this.fillRect = false

true to draw shape as a filled rectangle.

### strokeRect

> this.strokeRect = false

true to draw shape as a stroked rectangle.

### clearRect

> this.clearRect = false

true to cear a rectangle.

### strokeStyle

> this.strokeStyle = '#999999'

css color spec for the stoke style

### fillStyle

> this.fillStyle = '#999999'

css color spec for the fill style.

### Functions

### draw

> $.jqplot.ShapeRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws the shape.

ctx | canvas drawing context
points | array of points for shapes or [x, y, width, height] for rectangles or [x, y, radius, start angle (rad), end angle (rad)] for circles and arcs.

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.fill = false

whether to fill the shape.

> this.isarc = false

whether the shadow is an arc or not.

> this.fillRect = false

true to draw shape as a filled rectangle.

> this.strokeRect = false

true to draw shape as a stroked rectangle.

> this.clearRect = false

true to cear a rectangle.

> this.strokeStyle = '#999999'

css color spec for the stoke style

> this.fillStyle = '#999999'

css color spec for the fill style.

> $.jqplot.ShapeRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws the shape.
Close